@@ -90,7 +90,10 @@ class GuardianQuerySet(QuerySet):
             self._validated_opers["view"] = True
             self._validated_opers["change"] = True
             self._validated_opers["delete"] = True
-            return self.filter(user=user)
+            if user.is_superuser:
+                return self
+            else:
+                return self.filter(user=user)
             # return self
         else:
             clone = get_objects_for_user(user, [perm + "_" + self.model_name for perm in perms], klass=self)
