@@ -69,7 +69,7 @@ class ValidateForeignKeyUserMixin(serializers.Serializer):
                         if name == self.get_user_field_name():
                             if data[self.get_user_field_name()] != current_user:
                                 raise serializers.ValidationError("attempted to create foreign key on unauthorized object")
-                        elif not has_view_permissions(current_user, data[name]):
+                        elif name in data and not has_view_permissions(current_user, data):
                             raise serializers.ValidationError("attempted to create foreign key on unauthorized object")
         return data
 
